==> imp-doc-2.2.1.tar.gz: html/classIMP_1_1algebra_1_1Rotation3D.js <==
var classIMP_1_1algebra_1_1Rotation3D =
[
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a7f9a88f4c31d4d8f2115beeda2a979a8", null ],
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a8f42f5508cb8f50832961b3c45af5077", null ],
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a6ac672270fcad45eeffb377404553e66", null ],
    [ "~Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a7b56ec2b6603537fb59998505a891c44", null ],
    [ "get_derivative", "classIMP_1_1algebra_1_1Rotation3D.html#a59b89ac91698f8806ebc47208ab97e7e", null ],
    [ "get_inverse", "classIMP_1_1algebra_1_1Rotation3D.html#a64277befc08357d6768b5f8cba5fdf56", null ],
    [ "get_quaternion", "classIMP_1_1algebra_1_1Rotation3D.html#aac89c996b82edc7aa141a6e821d1156e", null ],
    [ "get_rotated", "classIMP_1_1algebra_1_1Rotation3D.html#a6e8cb23dae55da2e45c157f5b0654108", null ],
    [ "get_rotated_one_coordinate", "classIMP_1_1algebra_1_1Rotation3D.html#a76bdfad7e869ff30554af843e6276236", null ],
    [ "get_rotation_matrix_row", "classIMP_1_1algebra_1_1Rotation3D.html#a3c5847cf24d860a0029e13a388a6360e", null ],
    [ "operator*", "classIMP_1_1algebra_1_1Rotation3D.html#a16a68aa93e72637d2a5e513714dc3a41", null ],
    [ "operator*", "classIMP_1_1algebra_1_1Rotation3D.html#add6b45584377d72708fa41d93cf0e912", null ],
    [ "operator/", "classIMP_1_1algebra_1_1Rotation3D.html#a1f4eed6fc383b00ae8c5430c42190d39", null ],
    [ "operator/=", "classIMP_1_1algebra_1_1Rotation3D.html#a754ca1baec7553d4487fa6bd532bf372", null ],
    [ "show", "classIMP_1_1algebra_1_1Rotation3D.html#a5a6cbed7f9663fb5f8e56a17b10f1139", null ],
    [ "compose", "classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4", null ]
];

==> imp-doc-2.3.1.tar.gz: html/classIMP_1_1algebra_1_1Rotation3D.js <==
var classIMP_1_1algebra_1_1Rotation3D =
[
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a7f9a88f4c31d4d8f2115beeda2a979a8", null ],
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a8f42f5508cb8f50832961b3c45af5077", null ],
    [ "Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a6ac672270fcad45eeffb377404553e66", null ],
    [ "~Rotation3D", "classIMP_1_1algebra_1_1Rotation3D.html#a7b56ec2b6603537fb59998505a891c44", null ],
    [ "get_derivative", "classIMP_1_1algebra_1_1Rotation3D.html#a59b89ac91698f8806ebc47208ab97e7e", null ],
    [ "get_inverse", "classIMP_1_1algebra_1_1Rotation3D.html#a64277befc08357d6768b5f8cba5fdf56", null ],
    [ "get_is_valid", "classIMP_1_1algebra_1_1Rotation3D.html#a65b6637966fb8c03f68f0154476dd634", null ],
    [ "get_quaternion", "classIMP_1_1algebra_1_1Rotation3D.html#aac89c996b82edc7aa141a6e821d1156e", null ],
    [ "get_rotated", "classIMP_1_1algebra_1_1Rotation3D.html#a6e8cb23dae55da2e45c157f5b0654108", null ],
    [ "get_rotated_one_coordinate", "classIMP_1_1algebra_1_1Rotation3D.html#a76bdfad7e869ff30554af843e6276236", null ],
    [ "get_rotation_matrix_row", "classIMP_1_1algebra_1_1Rotation3D.html#a3c5847cf24d860a0029e13a388a6360e", null ],
    [ "operator*", "classIMP_1_1algebra_1_1Rotation3D.html#a16a68aa93e72637d2a5e513714dc3a41", null ],
    [ "operator*", "classIMP_1_1algebra_1_1Rotation3D.html#add6b45584377d72708fa41d93cf0e912", null ],
    [ "operator/", "classIMP_1_1algebra_1_1Rotation3D.html#a1f4eed6fc383b00ae8c5430c42190d39", null ],
    [ "operator/=", "classIMP_1_1algebra_1_1Rotation3D.html#a754ca1baec7553d4487fa6bd532bf372", null ],
    [ "show", "classIMP_1_1algebra_1_1Rotation3D.html#a5a6cbed7f9663fb5f8e56a17b10f1139", null ],
    [ "compose", "classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4", null ]
];
